pub struct AdviceStack { /* private fields */ }Expand description
Advice stack values ordered from top to bottom.
The front of the stack is the next element consumed by adv_push.
Implementations
Sourceimpl AdviceStack
impl AdviceStack
Sourcepub fn new() -> AdviceStack
pub fn new() -> AdviceStack
Creates a new empty advice stack.
Sourcepub fn try_from_values<I>(values: I) -> Result<AdviceStack, InputError>where
I: IntoIterator<Item = u64>,
pub fn try_from_values<I>(values: I) -> Result<AdviceStack, InputError>where
I: IntoIterator<Item = u64>,
Creates an advice stack from integer values ordered from top to bottom.
Errors
Returns an error if any value is not a valid field element.
Sourcepub fn iter(&self) -> impl Iterator<Item = &Felt>
pub fn iter(&self) -> impl Iterator<Item = &Felt>
Returns an iterator over elements from top to bottom.
Sourcepub fn append_element(&mut self, value: Felt) -> &mut AdviceStack
pub fn append_element(&mut self, value: Felt) -> &mut AdviceStack
Appends a single element to the bottom of the advice stack.
The appended element is consumed after all existing advice stack elements.
Sourcepub fn append_elements<I>(&mut self, values: I) -> &mut AdviceStackwhere
I: IntoIterator<Item = Felt>,
pub fn append_elements<I>(&mut self, values: I) -> &mut AdviceStackwhere
I: IntoIterator<Item = Felt>,
Appends raw elements to the bottom of the advice stack.
Values are ordered from top to bottom within the appended block.
Sourcepub fn prepend_elements<I>(&mut self, values: I) -> &mut AdviceStackwhere
I: IntoIterator<Item = Felt>,
pub fn prepend_elements<I>(&mut self, values: I) -> &mut AdviceStackwhere
I: IntoIterator<Item = Felt>,
Prepends raw elements ordered from top to bottom.
The first element in values becomes the next element consumed by advice operations.
Sourcepub fn push_element(&mut self, value: Felt) -> &mut AdviceStack
pub fn push_element(&mut self, value: Felt) -> &mut AdviceStack
Pushes a single element onto the top of the advice stack.
Sourcepub fn prepend_word(&mut self, word: Word) -> &mut AdviceStack
pub fn prepend_word(&mut self, word: Word) -> &mut AdviceStack
Prepends a word to the top of the advice stack.
Sourcepub fn prepend_stack(&mut self, stack: AdviceStack) -> &mut AdviceStack
pub fn prepend_stack(&mut self, stack: AdviceStack) -> &mut AdviceStack
Prepends another advice stack to the top of this stack.
Sourcepub fn append_for_adv_push(&mut self, slice: &[Felt]) -> &mut AdviceStack
pub fn append_for_adv_push(&mut self, slice: &[Felt]) -> &mut AdviceStack
Appends elements for consumption by multiple sequential adv_push instructions.
After repeat.n adv_push end, the operand stack will have slice[0] on top.
Sourcepub fn append_word(&mut self, word: Word) -> &mut AdviceStack
pub fn append_word(&mut self, word: Word) -> &mut AdviceStack
Appends a word for consumption by adv_loadw or adv_pushw.
Sourcepub fn append_dword(&mut self, words: [Word; 2]) -> &mut AdviceStack
pub fn append_dword(&mut self, words: [Word; 2]) -> &mut AdviceStack
Appends two words for consumption by adv_pipe.
Sourcepub fn append_for_adv_pipe(&mut self, slice: &[Felt]) -> &mut AdviceStack
pub fn append_for_adv_pipe(&mut self, slice: &[Felt]) -> &mut AdviceStack
Appends elements for sequential consumption by adv_pipe operations.
Panics
Panics if the slice length is not a multiple of 8 (double-word aligned).
Sourcepub fn consume_element(&mut self) -> Option<Felt>
pub fn consume_element(&mut self) -> Option<Felt>
Consumes a single element from the top of the advice stack.
Sourcepub fn consume_word(&mut self) -> Option<Word>
pub fn consume_word(&mut self) -> Option<Word>
Consumes a word from the top of the advice stack.
Sourcepub fn consume_dword(&mut self) -> Option<[Word; 2]>
pub fn consume_dword(&mut self) -> Option<[Word; 2]>
Consumes two words from the top of the advice stack.
Sourcepub fn into_elements(self) -> Vec<Felt>
pub fn into_elements(self) -> Vec<Felt>
Consumes self and returns elements ordered from top to bottom.