pub struct BoundedPowers<R>where
R: PrimeCharacteristicRing,{ /* private fields */ }Expand description
Same as Powers, but returns a bounded number of powers.
Implementations
Sourceimpl<F> BoundedPowers<F>where
F: Field,
impl<F> BoundedPowers<F>where
F: Field,
Sourcepub fn collect(self) -> Vec<F>
pub fn collect(self) -> Vec<F>
Collect exactly num_powers ascending powers of self.base, starting at self.current.
Details
The computation is split evenly amongst available threads, and each chunk is computed using packed fields. Small requests are computed on the current thread, as a parallel dispatch would cost more than the fill itself.
Performance
Enable the parallel feature to enable parallelization.