pub enum MastNode {
Block(BasicBlockNode),
Join(JoinNode),
Split(SplitNode),
Loop(LoopNode),
Call(CallNode),
Dyn(DynNode),
External(ExternalNode),
}Variants
Block(BasicBlockNode)
Join(JoinNode)
Split(SplitNode)
Loop(LoopNode)
Call(CallNode)
Dyn(DynNode)
External(ExternalNode)
Implementations
Sourceimpl MastNode
Public accessors
impl MastNode
Public accessors
Sourcepub fn is_external(&self) -> bool
pub fn is_external(&self) -> bool
Returns true if this node is an external node.
Sourcepub fn is_basic_block(&self) -> bool
pub fn is_basic_block(&self) -> bool
Returns true if this node is a basic block.
Sourcepub fn get_basic_block(&self) -> Option<&BasicBlockNode>
pub fn get_basic_block(&self) -> Option<&BasicBlockNode>
Returns the inner basic block node if the MastNode wraps a BasicBlockNode; None
otherwise.
Sourcepub fn unwrap_basic_block(&self) -> &BasicBlockNode
pub fn unwrap_basic_block(&self) -> &BasicBlockNode
Unwraps the inner basic block node if the MastNode wraps a BasicBlockNode; panics
otherwise.
Panics
Panics if the MastNode does not wrap a BasicBlockNode.
Sourcepub fn unwrap_join(&self) -> &JoinNode
pub fn unwrap_join(&self) -> &JoinNode
Sourcepub fn unwrap_split(&self) -> &SplitNode
pub fn unwrap_split(&self) -> &SplitNode
Sourcepub fn unwrap_loop(&self) -> &LoopNode
pub fn unwrap_loop(&self) -> &LoopNode
Sourcepub fn unwrap_call(&self) -> &CallNode
pub fn unwrap_call(&self) -> &CallNode
Sourcepub fn unwrap_dyn(&self) -> &DynNode
pub fn unwrap_dyn(&self) -> &DynNode
Sourcepub fn unwrap_external(&self) -> &ExternalNode
pub fn unwrap_external(&self) -> &ExternalNode
Unwraps the inner external node if the MastNode wraps a ExternalNode; panics
otherwise.
Panics
- if the
MastNodedoes not wrap aExternalNode.