BasicBlockNode

Struct BasicBlockNode 

pub struct BasicBlockNode { /* private fields */ }
Block for a linear sequence of operations (i.e., no branching or loops).

Executes its operations in order. Fails if any of the operations fails.

A basic block is composed of operation batches, operation batches are composed of operation groups, operation groups encode the VM’s operations and immediate values. These values are created according to these rules:

  • A basic block contains one or more batches.
  • A batch contains up to 8 groups, and the number of groups must be a power of 2.
  • A group contains up to 9 operations or 1 immediate value.
  • Last operation in a group cannot be an operation that requires an immediate value.
  • NOOPs are used to fill a group or batch when necessary.
  • An immediate value follows the operation that requires it, using the next available group in the batch. If there are no groups available in the batch, then both the operation and its immediate value are moved to the next batch.

Example: 8 pushes result in two operation batches:

  • First batch: First group with 7 push opcodes and 2 zero-paddings packed together, followed by 7 groups with their respective immediate values.
  • Second batch: First group with the last push opcode and 8 zero-paddings packed together, followed by one immediate and 6 padding groups.

The hash of a basic block is:

hash(batches, domain=BASIC_BLOCK_DOMAIN)

Where batches is the concatenation of each batch in the basic block, and each batch is 8 field elements (512 bits).

Implementations

Source

impl BasicBlockNode

Constants

pub const DOMAIN: Felt = ZERO

The domain of the basic block node (used for control block hashing).

Source

impl BasicBlockNode

Constructors

pub fn adjust_asm_op_indices( asm_op_indices: Vec<usize>, op_batches: &[OpBatch], ) -> Vec<usize>

Adjusts raw operation indices to padded indices for AssemblyOp mappings.

Adjusts AssemblyOp mappings (raw_idx, id) to account for padding NOOPs inserted into op_batches.

pub fn unadjust_asm_op_indices( asm_op_indices: Vec<usize>, op_batches: &[OpBatch], ) -> Vec<usize>

Adjusts padded operation indices back to raw indices for AssemblyOp mappings.

Source

impl BasicBlockNode

Public accessors

pub fn op_batches(&self) -> &[OpBatch]

Returns a reference to the operation batches in this basic block.

pub fn num_op_batches(&self) -> usize

Returns the number of operation batches in this basic block.

pub fn num_op_groups(&self) -> usize

Returns the total number of operation groups in this basic block.

Then number of operation groups is computed as follows:

  • For all batches but the last one we set the number of groups to 8, regardless of the actual number of groups in the batch. The reason for this is that when operation batches are concatenated together each batch contributes 8 elements to the hash.
  • For the last batch, we take the number of actual groups and round it up to the next power of two. The reason for rounding is that the VM always executes a number of operation groups which is a power of two.
pub fn num_operations(&self) -> u32

Returns the number of operations in this basic block.

pub fn operations(&self) -> impl Iterator<Item = &Operation>

Returns an iterator over the operations in the order in which they appear in the program.

pub fn raw_operations(&self) -> impl Iterator<Item = &Operation>

Returns an iterator over the un-padded operations in the order in which they appear in the program.

Source

impl BasicBlockNode

pub fn validate_batch_invariants(&self) -> Result<(), String>

Validates that this BasicBlockNode satisfies the core invariants:

  1. Non-final batches must be full (BATCH_SIZE groups), final batch must be power-of-two
  2. No operation group ends with an operation requiring an immediate value
  3. The last operation group in a batch cannot contain operations requiring immediate values
  4. OpBatch structural consistency (num_groups <= BATCH_SIZE, group size <= GROUP_SIZE)
  5. Immediate values are committed to empty groups and match group contents
  6. OpBatch padding semantics (no padding on empty groups; padded groups end with NOOP)

Returns an error string describing which invariant was violated if validation fails.