pub struct Program { /* private fields */ }Expand description
An executable program for Miden VM.
A program consists of a MAST forest, an entrypoint defining the MAST node at which the program execution begins, and a definition of the kernel against which the program must be executed (the kernel can be an empty kernel).
Implementations
Sourceimpl Program
Constructors
impl Program
Constructors
Sourcepub fn new(mast_forest: Arc<MastForest>, entrypoint: MastNodeId) -> Program
pub fn new(mast_forest: Arc<MastForest>, entrypoint: MastNodeId) -> Program
Sourcepub fn with_kernel(
mast_forest: Arc<MastForest>,
entrypoint: MastNodeId,
kernel: KernelDescriptor,
) -> Program
pub fn with_kernel( mast_forest: Arc<MastForest>, entrypoint: MastNodeId, kernel: KernelDescriptor, ) -> Program
Sourcepub fn with_advice_map(self, advice_map: AdviceMap) -> Program
pub fn with_advice_map(self, advice_map: AdviceMap) -> Program
Produces a new program with the existing MastForest and where all key/values in the
provided advice map are added to the internal advice map.
Sourceimpl Program
Public accessors
impl Program
Public accessors
Sourcepub fn hash(&self) -> Word
pub fn hash(&self) -> Word
Returns the hash of the program’s entrypoint.
Equivalently, returns the hash of the root of the entrypoint procedure.
Sourcepub fn entrypoint(&self) -> MastNodeId
pub fn entrypoint(&self) -> MastNodeId
Returns the entrypoint associated with this program.
Sourcepub fn mast_forest(&self) -> &Arc<MastForest> ⓘ
pub fn mast_forest(&self) -> &Arc<MastForest> ⓘ
Returns a reference to the underlying MastForest.
Sourcepub fn kernel(&self) -> &KernelDescriptor
pub fn kernel(&self) -> &KernelDescriptor
Returns the kernel associated with this program.
Sourcepub fn get_node_by_id(&self, node_id: MastNodeId) -> Option<&MastNode>
pub fn get_node_by_id(&self, node_id: MastNodeId) -> Option<&MastNode>
Returns the MastNode associated with the provided MastNodeId if valid, or else
None.
This is the fallible version of indexing (e.g. program[node_id]).
Sourcepub fn find_procedure_root(&self, digest: Word) -> Option<MastNodeId>
pub fn find_procedure_root(&self, digest: Word) -> Option<MastNodeId>
Returns the MastNodeId of the procedure root associated with a given digest, if any.
Sourcepub fn num_procedures(&self) -> u32
pub fn num_procedures(&self) -> u32
Returns the number of procedures in this program.
Sourcepub fn to_info(&self) -> ProgramInfo
pub fn to_info(&self) -> ProgramInfo
Returns basic information about this program (i.e., program hash and kernel).