pub struct StackOutputs { /* private fields */ }Expand description
Defines the final state of the VM’s operand stack at the end of program execution.
The first element is at position 0 (top of stack).
Implementations
Sourceimpl StackOutputs
impl StackOutputs
Sourcepub fn new(values: &[Felt]) -> Result<StackOutputs, OutputError>
pub fn new(values: &[Felt]) -> Result<StackOutputs, OutputError>
Constructs a new StackOutputs struct from the provided stack elements.
Errors
Returns an error if the number of stack elements is greater than MIN_STACK_DEPTH (16).
Sourcepub fn get_element(&self, idx: usize) -> Option<Felt>
pub fn get_element(&self, idx: usize) -> Option<Felt>
Returns the element located at the specified position on the stack or None if out of
bounds.
Sourcepub fn get_word(&self, idx: usize) -> Option<Word>
pub fn get_word(&self, idx: usize) -> Option<Word>
Returns the word located starting at the specified Felt position on the stack in
little-endian order, or None if out of bounds.
For example, passing in 0 returns the word at the top of the stack, and passing in 4
returns the word starting at element index 4.
Stack element N will be at position 0 of the word, N+1 at position 1, N+2 at position 2,
and N+3 at position 3. Word[0] corresponds to the top of the stack.
Sourcepub fn get_num_elements(&self, num_outputs: usize) -> &[Felt]
pub fn get_num_elements(&self, num_outputs: usize) -> &[Felt]
Returns the number of requested elements up to the maximum available in the stack outputs.