pub struct InFlightDiagnosticBuilder<'h> { /* private fields */ }Expand description
Constructs an in-flight diagnostic using the builder pattern
Implementations
Sourceimpl<'h> InFlightDiagnosticBuilder<'h>
impl<'h> InFlightDiagnosticBuilder<'h>
Sourcepub fn with_message(
self,
message: impl ToString,
) -> InFlightDiagnosticBuilder<'h>
pub fn with_message( self, message: impl ToString, ) -> InFlightDiagnosticBuilder<'h>
Sets the primary diagnostic message to message
Sourcepub fn with_code(self, code: impl ToString) -> InFlightDiagnosticBuilder<'h>
pub fn with_code(self, code: impl ToString) -> InFlightDiagnosticBuilder<'h>
Sets the error code for this diagnostic
Sourcepub fn with_url(self, url: impl ToString) -> InFlightDiagnosticBuilder<'h>
pub fn with_url(self, url: impl ToString) -> InFlightDiagnosticBuilder<'h>
Sets the error url for this diagnostic
Sourcepub fn with_primary_span(
self,
span: SourceSpan,
) -> InFlightDiagnosticBuilder<'h>
pub fn with_primary_span( self, span: SourceSpan, ) -> InFlightDiagnosticBuilder<'h>
Adds a primary label for span to this diagnostic, with no label message.
Sourcepub fn with_primary_label(
self,
span: SourceSpan,
message: impl ToString,
) -> InFlightDiagnosticBuilder<'h>
pub fn with_primary_label( self, span: SourceSpan, message: impl ToString, ) -> InFlightDiagnosticBuilder<'h>
Adds a primary label for span to this diagnostic, with the given message
A primary label is one which should be rendered as the relevant source code at which a diagnostic originates. Secondary labels are used for related items involved in the diagnostic.
Sourcepub fn with_secondary_label(
self,
span: SourceSpan,
message: impl ToString,
) -> InFlightDiagnosticBuilder<'h>
pub fn with_secondary_label( self, span: SourceSpan, message: impl ToString, ) -> InFlightDiagnosticBuilder<'h>
Adds a secondary label for span to this diagnostic, with the given message
A secondary label is used to point out related items in the source code which are relevant to the diagnostic, but which are not themselves the point at which the diagnostic originates.
Sourcepub fn with_help(self, note: impl ToString) -> InFlightDiagnosticBuilder<'h>
pub fn with_help(self, note: impl ToString) -> InFlightDiagnosticBuilder<'h>
Adds a note to the diagnostic
Notes are used for explaining general concepts or suggestions related to a diagnostic, and are not associated with any particular source location. They are always rendered after the other diagnostic content.
Sourcepub fn into_report(self) -> Report
pub fn into_report(self) -> Report
Consume this InFlightDiagnosticBuilder and create a Report
Sourcepub fn emit(self)
pub fn emit(self)
Emit the underlying Diagnostic via the configured DiagnosticsHandler