#[repr(C)]pub struct Word {
pub a: Felt,
pub b: Felt,
pub c: Felt,
pub d: Felt,
}Expand description
A unit of data consisting of 4 field elements.
For ordering a word with Ord the word’s elements are treated as limbs of an integer
in little-endian limb order and thus comparison starts from the most significant element.
Fields
a: FeltThe underlying elements of this word.
b: Feltc: Feltd: FeltImplementations
Sourceimpl Word
impl Word
Sourcepub const NUM_ELEMENTS: usize = 4
pub const NUM_ELEMENTS: usize = 4
The number of field elements in the word.
Sourcepub const SERIALIZED_SIZE: usize = 32
pub const SERIALIZED_SIZE: usize = 32
The serialized size of the word in bytes.
Sourcepub const fn into_elements(self) -> [Felt; 4]
pub const fn into_elements(self) -> [Felt; 4]
Returns the elements of this word as an array.
Sourcepub const fn parse(hex: &str) -> Result<Word, &'static str>
pub const fn parse(hex: &str) -> Result<Word, &'static str>
Parses a hex string into a new Word.
The input must contain valid hex prefixed with 0x. The input after the prefix
must contain between 0 and 64 characters (inclusive).
The input is interpreted to have little-endian byte ordering. Nibbles are interpreted to have big-endian ordering so that “0x10” represents Felt::new(16), not Felt::new(1).
This function is usually used via the word! macro.
use miden_field::{Felt, Word, word};
let word = word!("0x1000000000000000200000000000000030000000000000004000000000000000");
assert_eq!(
word,
Word::new([
Felt::new_unchecked(16),
Felt::new_unchecked(32),
Felt::new_unchecked(48),
Felt::new_unchecked(64)
])
);Sourcepub fn as_elements(&self) -> &[Felt]
pub fn as_elements(&self) -> &[Felt]
Returns the word as a slice of field elements.
Sourcepub fn words_as_elements_iter<'a, I>(words: I) -> impl Iterator<Item = &'a Felt>
pub fn words_as_elements_iter<'a, I>(words: I) -> impl Iterator<Item = &'a Felt>
Returns an iterator over the elements of multiple words.
Sourcepub fn words_as_elements(words: &[Word]) -> &[Felt]
pub fn words_as_elements(words: &[Word]) -> &[Felt]
Returns all elements of multiple words as a slice.