ColMatrix

Struct ColMatrix 

pub struct ColMatrix<E> { /* private fields */ }

Implementations

Source

impl<E> ColMatrix<E>
where E: Clone + Copy,

pub fn new(columns: Vec<Vec<E>>) -> ColMatrix<E>

Returns a new ColMatrix instantiated with the data from the specified columns.

Panics

Panics if:

  • The provided vector of columns is empty.
  • Not all of the columns have the same number of elements.
  • Number of rows is smaller than or equal to 1.
  • Number of rows is not a power of two.
pub fn num_cols(&self) -> usize

Returns the number of columns in this matrix.

pub fn num_rows(&self) -> usize

Returns the number of rows in this matrix.

pub fn get(&self, col_idx: usize, row_idx: usize) -> E

Returns the element located at the specified column and row indexes in this matrix.

Panics

Panics if either col_idx or row_idx are out of bounds for this matrix.

pub fn get_column(&self, col_idx: usize) -> &[E]

Returns a reference to the column at the specified index.

pub fn get_column_mut(&mut self, col_idx: usize) -> &mut [E]

Returns a reference to the column at the specified index.

pub fn columns(&self) -> impl Iterator<Item = &[E]>

Returns an iterator over all columns in this matrix.

pub fn read_row_into(&self, row_idx: usize, row: &mut [E])

Copies values of all columns at the specified row into the specified row slice.

Panics

Panics if row_idx is out of bounds for this matrix.

pub fn update_row(&mut self, row_idx: usize, row: &[E])

Updates a row in this matrix at the specified index to the provided data.

Panics

Panics if row_idx is out of bounds for this matrix.

pub fn merge_column(&mut self, column: Vec<E>)

Merges a column to the end of the matrix provided its length matches the matrix.

Panics

Panics if the column has a different length to other columns in the matrix.

pub fn remove_column(&mut self, index: usize) -> Vec<E>

Removes a column of the matrix given its index.

Panics

Panics if the column index is out of range.