pub struct IndexVec<I, T>where
I: Idx,{ /* private fields */ }Expand description
A dense vector indexed by ID types.
This provides O(1) access and storage for dense ID-indexed data.
Implementations
Sourceimpl<I, T> IndexVec<I, T>where
I: Idx,
impl<I, T> IndexVec<I, T>where
I: Idx,
Sourcepub fn with_capacity(n: usize) -> IndexVec<I, T>
pub fn with_capacity(n: usize) -> IndexVec<I, T>
Create a new IndexVec with pre-allocated capacity.
Sourcepub fn push(&mut self, v: T) -> Result<I, IndexedVecError>
pub fn push(&mut self, v: T) -> Result<I, IndexedVecError>
Push an element and return its ID.
Returns an error if the length would exceed the maximum representable by the ID type.
Sourcepub fn get(&self, idx: I) -> Option<&T>
pub fn get(&self, idx: I) -> Option<&T>
Get an element by ID, returning None if the ID is out of bounds.
Sourcepub fn into_inner(self) -> Vec<T>
pub fn into_inner(self) -> Vec<T>
Consume this IndexVec and return the underlying Vec.
Sourcepub fn swap_remove(&mut self, index: usize) -> T
pub fn swap_remove(&mut self, index: usize) -> T
Remove an element at the specified index and return it.