pub struct BasicBlockNode { /* private fields */ }Expand description
Block for a linear sequence of operations (i.e., no branching or loops).
Executes its operations in order. Fails if any of the operations fails.
A basic block is composed of operation batches, operation batches are composed of operation groups, operation groups encode the VM’s operations and immediate values. These values are created according to these rules:
- A basic block contains one or more batches.
- A batch contains up to 8 groups, and the number of groups must be a power of 2.
- A group contains up to 9 operations or 1 immediate value.
- Last operation in a group cannot be an operation that requires an immediate value.
- NOOPs are used to fill a group or batch when necessary.
- An immediate value follows the operation that requires it, using the next available group in the batch. If there are no groups available in the batch, then both the operation and its immediate value are moved to the next batch.
Example: 8 pushes result in two operation batches:
- First batch: First group with 7 push opcodes and 2 zero-paddings packed together, followed by 7 groups with their respective immediate values.
- Second batch: First group with the last push opcode and 8 zero-paddings packed together, followed by one immediate and 6 padding groups.
The hash of a basic block is:
hash(batches, domain=BASIC_BLOCK_DOMAIN)
Where batches is the concatenation of each batch in the basic block, and each batch is 8
field elements (512 bits).
Implementations
Sourceimpl BasicBlockNode
Constants
impl BasicBlockNode
Constants
Sourceimpl BasicBlockNode
Constructors
impl BasicBlockNode
Constructors
pub fn adjust_decorators( decorators: Vec<(usize, DecoratorId)>, op_batches: &[OpBatch], ) -> Vec<(usize, DecoratorId)>
Sourcepub fn adjust_asm_op_indices<T>(
asm_ops: Vec<(usize, T)>,
op_batches: &[OpBatch],
) -> Vec<(usize, T)>where
T: Copy,
pub fn adjust_asm_op_indices<T>(
asm_ops: Vec<(usize, T)>,
op_batches: &[OpBatch],
) -> Vec<(usize, T)>where
T: Copy,
Adjusts raw operation indices to padded indices for AssemblyOp mappings.
Similar to adjust_decorators, but works with AssemblyOp mappings (raw_idx, id) pairs.
The op_batches contain padding NOOPs that shift operation indices. This method adjusts
the raw indices to account for this padding so lookups during execution use correct indices.
Sourceimpl BasicBlockNode
Public accessors
impl BasicBlockNode
Public accessors
Sourcepub fn op_batches(&self) -> &[OpBatch]
pub fn op_batches(&self) -> &[OpBatch]
Returns a reference to the operation batches in this basic block.
Sourcepub fn num_op_batches(&self) -> usize
pub fn num_op_batches(&self) -> usize
Returns the number of operation batches in this basic block.
Sourcepub fn num_op_groups(&self) -> usize
pub fn num_op_groups(&self) -> usize
Returns the total number of operation groups in this basic block.
Then number of operation groups is computed as follows:
- For all batches but the last one we set the number of groups to 8, regardless of the actual number of groups in the batch. The reason for this is that when operation batches are concatenated together each batch contributes 8 elements to the hash.
- For the last batch, we take the number of actual groups and round it up to the next power of two. The reason for rounding is that the VM always executes a number of operation groups which is a power of two.
Sourcepub fn num_operations(&self) -> u32
pub fn num_operations(&self) -> u32
Returns the number of operations in this basic block.
Sourcepub fn indexed_decorator_iter<'a>(
&'a self,
forest: &'a MastForest,
) -> DecoratorOpLinkIterator<'a> ⓘ
pub fn indexed_decorator_iter<'a>( &'a self, forest: &'a MastForest, ) -> DecoratorOpLinkIterator<'a> ⓘ
Returns a DecoratorOpLinkIterator which allows us to iterate through the op-indexed
decorators of this basic block node.
This method borrows from the forest’s storage, avoiding unnecessary Arc clones and providing efficient access to decorators.
This iterator is intended for e.g. processor consumption and provides access to only the
operation-indexed decorators (excluding before_enter and after_exit decorators).
Sourcepub fn raw_decorator_iter<'a>(
&'a self,
forest: &'a MastForest,
) -> RawDecoratorOpLinkIterator<'a>
pub fn raw_decorator_iter<'a>( &'a self, forest: &'a MastForest, ) -> RawDecoratorOpLinkIterator<'a>
Returns an iterator which allows us to iterate through the decorator list of this basic block node with op indexes aligned to the “raw” (un-padded)) op batches of the basic block node.
Though this adjusts the indexation of op-indexed decorators, this iterator returns all
decorators of the BasicBlockNode in the order in which they appear in the program.
This includes before_enter, op-indexed decorators, and after_exit.
Returns an iterator which allows us to iterate through the decorator list of this basic block node with op indexes aligned to the “raw” (un-padded)) op batches of the basic block node.
This method borrows from the forest’s storage, avoiding unnecessary Arc clones and providing efficient access to decorators.
Though this adjusts the indexation of op-indexed decorators, this iterator returns all
decorators of the BasicBlockNode in the order in which they appear in the program.
This includes before_enter, op-indexed decorators, and after_exit`.
Sourcepub fn raw_op_indexed_decorators(
&self,
forest: &MastForest,
) -> Vec<(usize, DecoratorId)>
pub fn raw_op_indexed_decorators( &self, forest: &MastForest, ) -> Vec<(usize, DecoratorId)>
Returns only the raw op-indexed decorators (without before_enter/after_exit) with indices based on raw operations.
Stores decorators with raw operation indices for serialization.
Returns only the raw op-indexed decorators (without before_enter/after_exit) with indices based on raw operations.
This method borrows from the forest’s storage, avoiding unnecessary Arc clones and providing efficient access to decorators.
Stores decorators with raw operation indices for serialization.
Sourcepub fn operations(&self) -> impl Iterator<Item = &Operation>
pub fn operations(&self) -> impl Iterator<Item = &Operation>
Returns an iterator over the operations in the order in which they appear in the program.
Sourcepub fn raw_operations(&self) -> impl Iterator<Item = &Operation>
pub fn raw_operations(&self) -> impl Iterator<Item = &Operation>
Returns an iterator over the un-padded operations in the order in which they appear in the program.
Sourcepub fn num_operations_and_decorators(&self, forest: &MastForest) -> u32
pub fn num_operations_and_decorators(&self, forest: &MastForest) -> u32
Returns the total number of operations and decorators in this basic block.
Sourcepub fn linked_id(&self) -> Option<MastNodeId>
pub fn linked_id(&self) -> Option<MastNodeId>
Return the MastNodeId of this BasicBlockNode, if in Linked state
Sourceimpl BasicBlockNode
impl BasicBlockNode
Sourcepub fn validate_batch_invariants(&self) -> Result<(), String>
pub fn validate_batch_invariants(&self) -> Result<(), String>
Validates that this BasicBlockNode satisfies the core invariants:
- Non-final batches must be full (BATCH_SIZE groups), final batch must be power-of-two
- No operation group ends with an operation requiring an immediate value
- The last operation group in a batch cannot contain operations requiring immediate values
- OpBatch structural consistency (num_groups <= BATCH_SIZE, group size <= GROUP_SIZE)
- Immediate values are committed to empty groups and match group contents
- OpBatch padding semantics (no padding on empty groups; padded groups end with NOOP)
Returns an error string describing which invariant was violated if validation fails.