pub struct SplitNode { /* private fields */ }Expand description
A Split node defines conditional execution. When the VM encounters a Split node it executes
either the on_true child or on_false child.
Which child is executed is determined based on the top of the stack. If the value is 1, then
the on_true child is executed. If the value is 0, then the on_false child is executed. If
the value is neither 0 nor 1, the execution fails.
Implementations
Sourceimpl SplitNode
Public accessors
impl SplitNode
Public accessors
Sourcepub fn on_true(&self) -> MastNodeId
pub fn on_true(&self) -> MastNodeId
Returns the ID of the node which is to be executed if the top of the stack is 1.
Sourcepub fn on_false(&self) -> MastNodeId
pub fn on_false(&self) -> MastNodeId
Returns the ID of the node which is to be executed if the top of the stack is 0.