pub struct ExecutionProof {
pub proof: Vec<u8>,
pub hash_fn: HashFunction,
pub pc_requests: Vec<PrecompileRequest>,
}Expand description
A proof of correct execution of Miden VM.
The proof contains the STARK proof, the hash function used during proof generation, and a set of precompile requests deferred during proof generation. However, the proof does not contain public inputs needed to verify the proof.
Fields
proof: Vec<u8>hash_fn: HashFunctionpc_requests: Vec<PrecompileRequest>Implementations
Sourceimpl ExecutionProof
impl ExecutionProof
Sourcepub const fn new(
proof: Vec<u8>,
hash_fn: HashFunction,
pc_requests: Vec<PrecompileRequest>,
) -> ExecutionProof
pub const fn new( proof: Vec<u8>, hash_fn: HashFunction, pc_requests: Vec<PrecompileRequest>, ) -> ExecutionProof
Creates a new instance of ExecutionProof from the specified STARK proof, hash function, and list of all deferred PrecompileRequests.
Sourcepub fn stark_proof(&self) -> &[u8] ⓘ
pub fn stark_proof(&self) -> &[u8] ⓘ
Returns the underlying STARK proof.
Sourcepub const fn hash_fn(&self) -> HashFunction
pub const fn hash_fn(&self) -> HashFunction
Returns the hash function used during proof generation process.
Sourcepub fn precompile_requests(&self) -> &[PrecompileRequest]
pub fn precompile_requests(&self) -> &[PrecompileRequest]
Returns the list of precompile requests made during the execution of the program.
Sourcepub fn security_level(&self) -> u32
pub fn security_level(&self) -> u32
Returns conjectured security level of this proof in bits.
Currently returns a hardcoded 96 bits. Once the security estimator is implemented in Plonky3, this should calculate the actual conjectured security level based on:
- Proof parameters (FRI folding factor, number of queries, etc.)
- Hash function collision resistance
- Field size and extension degree
Sourcepub fn from_bytes(source: &[u8]) -> Result<ExecutionProof, DeserializationError>
pub fn from_bytes(source: &[u8]) -> Result<ExecutionProof, DeserializationError>
Reads the source bytes, parsing a new proof instance.
The serialization layout matches the Serializable implementation of ExecutionProof.
Sourcepub fn into_parts(self) -> (HashFunction, Vec<u8>, Vec<PrecompileRequest>)
pub fn into_parts(self) -> (HashFunction, Vec<u8>, Vec<PrecompileRequest>)
Returns the hash function, proof bytes, and precompile requests.